@@ -1,7 +1,7 @@
 package BenchmarkAnything::Storage::Backend::SQL::Search::MCE;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: searchengine support functions using MCE
-$BenchmarkAnything::Storage::Backend::SQL::Search::MCE::VERSION = '0.027';
+$BenchmarkAnything::Storage::Backend::SQL::Search::MCE::VERSION = '0.028';
 use MCE::Flow;
 
 
@@ -18,7 +18,7 @@ sub sync_search_engine_mce
                      bounds_only => 1);
     mce_flow_s sub {
         BenchmarkAnything::Storage::Backend::SQL::Search::_sync_search_engine_process_chunk ($or_sql, $b_force, $_->[0], $_->[1]);
-    }, 1, $i_count_datapoints;
+    }, $i_start, $i_count_datapoints;
 }
 
 1;
